Learn R Programming

additivityTests (version 1.0.0)

Boik: Multi-headed Machine Data

Description

Performance of a multiple-headed machine used to fill bottles. Weights for six heads on five occasions were recorded.

Arguments

source

Robert J. Boik: A comparison of three invariant tests of additivity in two-way classifications with no replications, Computational Statistics & Data Analysis, 1993.