Learn R Programming

additivityTests (version 1.0.0)

johnson.graybill.test: Johnson and Graybill Additivity Test

Description

Test for an interaction in two-way ANOVA table by the Johnson-Graybill test.

Usage

johnson.graybill.test(Y, alpha = 0.05,
    critical.value = NA, Nsim = 1000)

Arguments

Y
data matrix
alpha
level of the test
critical.value
result of critical.values function, see Details
Nsim
number of simulations to be used for a critical value estimation

Value

  • A list with class "aTest" containing the following components: test statistics stat, critical value critical.value and the result of the test result, i.e. whether the additivity hypothesis has been rejected.

Details

The critical value can be computed in advance and given in the parameter critical value. If not a function critical.values is called to do that.

References

Johnson, D.E. and Graybill, F.A.: An analysis of a two-way model with interaction and no replication, Journal of the American Statistical Association 67, pp. 862--868, 1972.

See Also

tukey.test, mtukey.test, mandel.test, lbi.test, tussel.test

Examples

Run this code
data(Boik)
johnson.graybill.test(Boik)

Run the code above in your browser using DataLab