Learn R Programming

additivityTests (version 1.0.0)

lbi.test: Locally Best Invariant (LBI) Additivity Test

Description

Test for an interaction in two-way ANOVA table by the LBI test.

Usage

lbi.test(Y, alpha = 0.05, critical.value = NA,
    Nsim = 1000)

Arguments

Y
data matrix
alpha
level of the test
critical.value
result of critical.values function, see Details
Nsim
number of simulations to be used for a critical value estimation

Value

  • A list with class "aTest" containing the following components: test statistics stat, critical value critical.value and the result of the test result, i.e. whether the additivity hypothesis has been rejected.

Details

The critical value can be computed in advance and given in the parameter critical value. If not a function critical.values is called to do that.

References

Boik, R.J.: Testing additivity in two-way classifications with no replications:the locally best invariant test, Journal of Applied Statistics 20,pp. 41--55, 1993.

See Also

tukey.test, mtukey.test, mandel.test, johnson.graybill.test, tussel.test

Examples

Run this code
data(Boik)
lbi.test(Boik)

Run the code above in your browser using DataLab